/// <reference path="../App.js" />
/*global app*/

(function () {
	'use strict';

	// The initialize function must be run each time a new page is loaded
	Office.initialize = function (reason) {
		$(document).ready(function () {
			app.initialize();
						
			// 起動時に従業員情報を取得しドロップダウンリストを生成する。
            setEmployeeName();

			// ドロップダウンリストのchangeイベントを追加する。
            $('#employee-list').change(searchEmployee);
			
			// 申請ボタンのclickイベントを追加する。
            $('#apply').click(getNewAddressFromTaskPane);
		});
	};
			
	// Step1 従業員情報の取得　Employeeシートより値を取得しドロップダウンリストを生成する。
    function setEmployeeName() {
		Office.context.document.bindings.addFromNamedItemAsync('Employee!MASTER_ALL', 
		Office.BindingType.Matrix, {id: 'MASTER_ALL' }, function (asyncResult) {
			if (asyncResult.status === Office.AsyncResultStatus.Succeeded) {
				Office.select('bindings#MASTER_ALL').getDataAsync(function (employeeMasterResult) {
					if (employeeMasterResult.status === Office.AsyncResultStatus.Failed) {
						app.showNotification('Masterシートの値の取得に失敗しました。: ' +
						 employeeMasterResult.error.message);
					} else {
						$('#employee-list').append($('<option>').html(' ').val(0));
						
						var employeeMaster = employeeMasterResult.value;
						for (var i = 0; i < employeeMaster.length; i++) {
							var employeeId = '';
							var employeeName = '';
							
							// 0列目をドロップダウンリストの値にする。(ここではID。)
							if (employeeMaster[i][0]) {
								employeeId = employeeMaster[i][0];
							}
							
							// 1列目をドロップダウンリストの表示する項目名にする。(ここでは従業員名。)
							if (employeeMaster[i][1]) {
								employeeName = employeeMaster[i][1];
							}
							
							if (employeeId !== '') {
								$('#employee-list').append($('<option>').html(employeeName).val(employeeId));
							}
						}
					}
				});
			}
		});
    }

	// 従業員情報の検索、EmployeeシートよりIDがemployeeId(ドロップダウンリストにて選択中の値)と一致するものを探し
	// setEmployeeToExcelSheetに渡す。
    function searchEmployee () {
        var employeeId = parseInt($('#employee-list').val(), 10);
		
		Office.select('bindings#MASTER_ALL').getDataAsync(function (asyncResult) {
			if (asyncResult.status === Office.AsyncResultStatus.Succeeded) {
				for (var i = 0; i < asyncResult.value.length; i++) {
					if (asyncResult.value[i][0]　&& asyncResult.value[i][0] === employeeId) {
						setEmployeeToExcelSheet(asyncResult.value[i][1], 
						asyncResult.value[i][2], asyncResult.value[i][3])
						break;
					}
				}
			} else {
				app.showNotification('Masterシートの値の取得に失敗しました。: ' + asyncResult.error.message);
			}
		});
    }

	// 従業員情報をUpdateFormに設定する。
	function setEmployeeToExcelSheet (employeeName, postalCode, address) {
		// UpdateFormに対して氏名設定を行う。
		Office.context.document.bindings.addFromNamedItemAsync('UpdateForm!EMPLOYEE_NAME', 
		Office.BindingType.Matrix, { id: 'EMPLOYEE_NAME' }, function (asyncResult) {
			if (asyncResult.status === Office.AsyncResultStatus.Succeeded) {
				Office.select('bindings#EMPLOYEE_NAME').setDataAsync(employeeName, 
				{ coercionType: Office.CoercionType.Matrix }, function (employeeNameCell) {
					if (employeeNameCell.status === Office.AsyncResultStatus.Failed) {
						app.showNotification('氏名設定に失敗しました。: '  + employeeNameCell.error.message);
					}
				});
			} else {
				app.showNotification('氏名のbindingsへの追加に失敗しました。: ' + asyncResult.error.message);
			}
		});
		// UpdateFormに対して郵便番号設定を行う。
		Office.context.document.bindings.addFromNamedItemAsync('UpdateForm!CURRENT_POSTAL_CODE', 
		Office.BindingType.Matrix, { id: 'CURRENT_POSTAL_CODE' }, function (asyncResult) {
	        if (asyncResult.status === Office.AsyncResultStatus.Succeeded) {
	            Office.select('bindings#CURRENT_POSTAL_CODE').setDataAsync(postalCode, 
				{ coercionType: Office.CoercionType.Matrix }, function (currentPostalCodeCell) {
	                if (currentPostalCodeCell.status === Office.AsyncResultStatus.Failed) {
	                    app.showNotification('郵便番号設定に失敗しました。: ' + currentPostalCodeCell.error.message);
	                }
	            });
	        } else {
	            app.showNotification('郵便番号のbindingsへの追加に失敗しました。: ' + asyncResult.error.message);
	        }
	    });
        // UpdateFormに対して住所設定を行う。
        Office.context.document.bindings.addFromNamedItemAsync('UpdateForm!CURRENT_ADDRESS',
		Office.BindingType.Matrix, { id: 'CURRENT_ADDRESS' }, function (asyncResult) {
            if (asyncResult.status === Office.AsyncResultStatus.Succeeded) {
                Office.select('bindings#CURRENT_ADDRESS').setDataAsync(address, 
				{ coercionType: Office.CoercionType.Matrix }, function (currentAddressCell) {
                    if (currentAddressCell.status === Office.AsyncResultStatus.Failed) {
                        app.showNotification('住所設定に失敗しました。: ' + currentAddressCell.error.message);
                    }
                });
            } else {
                app.showNotification('住所のbindingsへの追加に失敗しました。: ' + asyncResult.error.message);
            }
        });
	} 

	// Step2 HTMLより住所更新情報を取得する。
    function getNewAddressFromTaskPane() {
		var employeeId = $('#employee-list').val();
        var postalCd = $('#new-postal-code').val();
        var newAddress = $('#new-address').val();
		
        Office.select('bindings#MASTER_ALL').getDataAsync(function (asyncResult) {
            if (asyncResult.status === Office.AsyncResultStatus.Succeeded) {
                setNewAddress(employeeId, postalCd, newAddress);
            } else {
                app.showNotification('Masterシートの値の取得に失敗しました。: ' + asyncResult.error.message);
            }
        });
    }
	
	// 新しい住所と郵便番号をUpdateFormとUpdateLogに設定する。
	function setNewAddress(newEmployeeId, newPostalCode, newAddress) {
		// 新郵便番号をUpdateFormに設定する。
		Office.context.document.bindings.addFromNamedItemAsync('UpdateForm!NEW_POSTAL_CODE', 
		Office.BindingType.Text, { id: 'NEW_POSTAL_CODE' },function (asyncResult) {
	        if (asyncResult.status === Office.AsyncResultStatus.Succeeded) {
	            Office.select('bindings#NEW_POSTAL_CODE').setDataAsync(newPostalCode, function (newPostalCodeCell) {
	                if (newPostalCodeCell.status === Office.AsyncResultStatus.Failed) {
	                    app.showNotification('新しい郵便番号の挿入に失敗しました。:' + newPostalCodeCell.error.message);
	                }
	            });
	        } else {
	            app.showNotification('新しい郵便番号のbindingsへの追加に失敗しました。: '　+ asyncResult.error.message);
	        }
	    });
		
        // 新住所をUpdateFormに設定する。
        Office.context.document.bindings.addFromNamedItemAsync('UpdateForm!NEW_ADDRESS', 
		Office.BindingType.Text, { id: 'NEW_ADDRESS' },function (asyncResult) {
            if (asyncResult.status === Office.AsyncResultStatus.Succeeded) {
                Office.select('bindings#NEW_ADDRESS').setDataAsync(newAddress, function (newAddressCell) {
                    if (newAddressCell.status === Office.AsyncResultStatus.Failed) {
                        app.showNotification('新しい住所の挿入に失敗しました。: ' + newAddressCell.error.message);
                    }
                });
            } else {
                app.showNotification('新しい住所のbindingsへの追加に失敗しました。: ' + asyncResult.error.message);
            }
        });
				
		// 従業員IDをUpdateLogに追加する。
		Office.context.document.bindings.addFromNamedItemAsync('UpdateLog!UPDATE_EMPLOYEE_NAME', 
		Office.BindingType.Text, { id: 'UPDATE_EMPLOYEE_NAME' },function (asyncResult) {
	        if (asyncResult.status === Office.AsyncResultStatus.Succeeded) {
	            Office.select('bindings#UPDATE_EMPLOYEE_NAME').setDataAsync(newEmployeeId, function (updateEmployeeId) {
	                if (updateEmployeeId.status === Office.AsyncResultStatus.Failed) {
	                    app.showNotification('従業員IDの変更申請リストへの挿入に失敗しました。: ' + 
						updateEmployeeId.error.message);
	                }
	            });
	        } else {
	            app.showNotification('従業員IDのbindingsへの追加に失敗しました。: ' + asyncResult.error.message);
	        }
	    });
		
		// 新郵便番号をUpdateLogに追加する。
		Office.context.document.bindings.addFromNamedItemAsync('UpdateLog!UPDATE_POSTAL_CODE', 
		Office.BindingType.Text, { id: 'UPDATE_POSTAL_CODE' },function (asyncResult) {
	        if (asyncResult.status === Office.AsyncResultStatus.Succeeded) {
	            Office.select('bindings#UPDATE_POSTAL_CODE').setDataAsync(newPostalCode, function (updatePostalCode) {
	                if (updatePostalCode.status === Office.AsyncResultStatus.Failed) {
	                    app.showNotification('新しい郵便番号の変更申請リストへの挿入に失敗しました。: ' + 
						updatePostalCode.error.message);
	                }
	            });
	        } else {
	            app.showNotification('新しい郵便番号のbindingsへの追加に失敗しました。: ' + asyncResult.error.message);
	        }
	    });
		
		// 新住所をUpdateLogに追加する。
        Office.context.document.bindings.addFromNamedItemAsync('UpdateLog!UPDATE_ADDRESS', 
		Office.BindingType.Text, { id: 'UPDATE_ADDRESS' },function (asyncResult) {
            if (asyncResult.status === Office.AsyncResultStatus.Succeeded) {
                Office.select('bindings#UPDATE_ADDRESS').setDataAsync(newAddress, function (updateAddress) {
                    if (updateAddress.status === Office.AsyncResultStatus.Failed) {
                        app.showNotification('新しい住所の変更申請リストへの挿入に失敗しました。: ' + 
						updateAddress.error.message);
                    }
                });
            } else {
                app.showNotification('新しい住所のbindingsへの追加に失敗しました。' + asyncResult.error.message);
            }
        });
	} 
})();
