'use strict';

// The initialize function must be run each time a new page is loaded
Office.initialize = function (reason) {
	$(document).ready(function () {
		
		// BingMapを呼び出しする。
		getMap();
	});
};

// 地図の検索を開始する。
function getQuery() {
	Office.context.document.getSelectedDataAsync(Office.CoercionType.Text, function (asyncResult) {
		if (asyncResult.status === Office.AsyncResultStatus.Failed) {
			writeToPage('Error:' + asyncResult.error.message);
		} else {
			// 取得したテキストを書き出す。
			// writeToPage(asyncResult.value);
			getMap();
			map.entities.clear();
			map.getCredentials(function (credentials) { 
				createGeocodeRequest(credentials, [asyncResult.value]);
			}); 
		}
	});
}

// テキストをHTML上に出力する。
function writeToPage(text) {
	$('#results').text(text);
}

// 必要な変数を追加する。
var map = null;
var searched = null; // searched location

// 地図呼び出す。
function getMap() {
	var options = {
		credentials:'Ak-0QlEvcCFJSHL2vb974uOV0jmTvPP4yfEXkyEUqN-fRCwNQNnRjlfJKmgS6TPT'
	};
	var mElement = $('#map')[0];
	map = new Microsoft.Maps.Map(mElement, options);
}

// BingMapへ問合せる。
function createGeocodeRequest(credentials, query) { 
	if (credentials === null) { 
		writeToPage('Credentials is null.'); 
		return; 
	} 
	
	$.each(query, function () { 
		var word = String(this); 
		if (word !== '') { 
			$.ajax({ 
				type: 'GET', 
				url: 'http://dev.virtualearth.net/REST/v1/Locations', 
				dataType: 'jsonp', 
				data: { 
					key: credentials, 
					query: word, 
					c: 'ja-JP', 
					o: 'json' 
				}, 
				jsonp: 'jsonp', 
				success: function (data, dataType) { 
					geocodeCallback(data, query.length === 1); 
				} 
			}); 
		} 
	}); 
} 

// 問合せ結果を出力する。
function geocodeCallback(response, isone) { 
	if (response && response.errorDetails) {
		var text = ''; 
		$.each(response.errorDetails, function () { 
			text += this + '\n'; 
		}); 
		writeToPage(text) 
		return false; 
	} 
	if (response && 
	response.resourceSets && 
	response.resourceSets.length > 0 && 
	response.resourceSets[0].resources && 
	response.resourceSets[0].resources.length > 0) { 
		
	// 地図に座標をセットする。
	if (isone) { 
		var coordinatesList = response.resourceSets[0].resources[0].bbox; 
		var bounds = Microsoft.Maps.LocationRect.fromLocations(
			new Microsoft.Maps.Location(coordinatesList[0], coordinatesList[1]), 
			new Microsoft.Maps.Location(coordinatesList[2], coordinatesList[3])); 
		map.setView({ bounds: bounds }); 
	} 
	// 地図にプッシュピンを追加する。
	var code = 'A'.charCodeAt(0); 
	
	$.each(response.resourceSets[0].resources, function () { 
		
		var point = this.point; 
		var location = new Microsoft.Maps.Location(point.coordinates[0], point.coordinates[1]); 
		
		searched = location; 
		
		var pin = new Microsoft.Maps.Pushpin(location, { text: String.fromCharCode(code++) }); 
		
		map.entities.push(pin); 
		}); 
	} 
} 

// 地図のURLをExcel上に出力する。
function setUrl() {
	var url = 'http://www.bing.com/maps/default.aspx?q=' + 
	encodeURI(searched.latitude + ',' + searched.longitude) + '&x=0&y=0&form=MSNH69&qs=n&sk=&mkt=ja-JP';
	Office.context.document.setSelectedDataAsync(url, { coercionType: Office.CoercionType.Text }, 
	function (asyncResult) {
		if (asyncResult.status === Office.AsyncResultStatus.Failed) {
			writeToPage(asyncResult.error.message);
		}
	});
}

// 地図の検索結果を再設定する準備をする。
function bindData() {
	Office.context.document.bindings.addFromSelectionAsync(Office.BindingType.Matrix, 
	{ id: 'myBinding' }, function (asyncResult) {
		if (asyncResult.status === Office.AsyncResultStatus.Failed) {
			writeToPage('Error: ' + asyncResult.error.message);
			return;
		}
	});	
	
	Office.select('bindings#myBinding').addHandlerAsync('bindingDataChanged', bindDataChanged);
	bindDataChanged();

}

// 地図はそのままで再度検索を実行する。
function bindDataChanged() {
	var binding = Office.select('bindings#myBinding');
	if (binding) { binding.getDataAsync(function (asyncResult) {
		// 地図のエンティティを一旦クリアする
		map.entities.clear();
		map.getCredentials(function (credentials) { 
			createGeocodeRequest(credentials, asyncResult.value); });
		});
	}
}