/// <reference path="../App.js" />
/*global app*/

(function () {
	'use strict';

	// The Office initialize function must be run each time a new page is loaded
	Office.initialize = function (reason) {
		$(document).ready(function () {
			app.initialize();
			
			// 新規入力＆編集画面保存ボタンクリックイベントを追加する。
			$('#save').click(saveSettings);
			
			// 情報表示画面編集ボタンクリックイベントを追加する。
			$('#edit').click(editSettings);
			
			displayItemDetails();
		});
	};

	// Displays the "Subject" and "From" fields, based on the current mail item
	function displayItemDetails() {
		var item = Office.context.mailbox.item;
		$('#subject').text(item.subject);

		var from;
		if (item.itemType === Office.MailboxEnums.ItemType.Message) {
			from = item.from;
		} else if (item.itemType === Office.MailboxEnums.ItemType.Appointment) {
			from = item.organizer;
		}

		if (from) {
			// $('#from').text(from.displayName);
			// $('#from').click(function () {
			// app.showNotification(from.displayName, from.emailAddress);
			// });
			searchSenderInfo(from);
		}
	}
	
	// roamingSettings内に送信者の情報が存在するか確認して表示画面もしくは入力画面を表示する。
	function searchSenderInfo(from) {
		var senderInfoArray = Office.context.roamingSettings.get(from.emailAddress);
		if (senderInfoArray) {
			showSenderInfo(from.emailAddress);
		} else {
			$('#from-email-address').text(from.emailAddress);
			$('#content-input').show();
		}
	}
	
	//　入力された情報をroamingSetttings内に保存する。
	function saveSettings() {
		var senderName = $('#sender-name').val();
		var senderCompany = $('#sender-company').val();
		var senderDivision = $('#sender-division').val();
		var senderPosition = $('#sender-position').val();
		var senderPostalCode = $('#sender-postal-code').val();
		var senderAddress = $('#sender-address').val();
		var senderTel = $('#sender-tel').val();
		var senderFax = $('#sender-fax').val();
		var senderURL = $('#sender-url').val();
		
		// 9つ分の配列を先に作成する。
		var senderInfoArray = ['','','','','','','','',''];
		
		if (senderName) {
			senderInfoArray[0] = senderName;
		}
		
		if (senderCompany) {
			senderInfoArray[1] = senderCompany;
		}
		
		if (senderDivision) {
			senderInfoArray[2] = senderDivision;
		}
		
		if (senderPosition) {
			senderInfoArray[3] = senderPosition;
		}
		
		if (senderPostalCode) {
			senderInfoArray[4] = senderPostalCode;
		}
		
		if (senderAddress) {
			senderInfoArray[5] = senderAddress;
		}
		
		if (senderTel) {
			senderInfoArray[6] = senderTel;
		}
		
		if (senderFax) {
			senderInfoArray[7] = senderFax;
		}
		
		if (senderURL) {
			senderInfoArray[8] = senderURL;
		}
		
		var fromEmailAddress = $('#from-email-address').text();
		Office.context.roamingSettings.set(fromEmailAddress, senderInfoArray);
		
		Office.context.roamingSettings.saveAsync(function (asyncResult) {
			if (asyncResult.status === Office.AsyncResultStatus.Failed) {
				app.showNotification(asyncResult.error.message);
			} else {
				showSenderInfo(fromEmailAddress);
			}
		});
	}
	
	// 送信者の情報をメールアプリ上に表示する。
	function showSenderInfo(fromEmailAddress) {
		var senderInfoArray = Office.context.roamingSettings.get(fromEmailAddress);
		
		if (fromEmailAddress) {
			$('#display-email-address').text(fromEmailAddress);
			$('#display-sender-name').text(senderInfoArray[0]);
			$('#display-sender-company').text(senderInfoArray[1]);
			$('#display-sender-division').text(senderInfoArray[2]);
			$('#display-sender-position').text(senderInfoArray[3]);
			$('#display-sender-postal-code').text(senderInfoArray[4]);
			$('#display-sender-address').text(senderInfoArray[5]);
			$('#display-sender-tel').text(senderInfoArray[6]);
			$('#display-sender-fax').text(senderInfoArray[7]);
			$('#display-sender-url').empty();
			$('#display-sender-url').append('<a href="' + senderInfoArray[8] + '" target="_blank">'+ senderInfoArray[8] + '</a>');
			
			$('#content-input').hide();
			$('#content-main').show();
		}
	}
	
	// 登録されている送信者の情報を編集する画面を表示する。
	function editSettings() {
		var emailAddress = $('#display-email-address').text();
		if (emailAddress) {
			var senderInfoArray = Office.context.roamingSettings.get(emailAddress);
			if (senderInfoArray) {
				$('#from-email-address').text(emailAddress);
				$('#sender-name').val(senderInfoArray[0]);
				$('#sender-company').val(senderInfoArray[1]);
				$('#sender-division').val(senderInfoArray[2]);
				$('#sender-position').val(senderInfoArray[3]);
				$('#sender-postal-code').val(senderInfoArray[4]);
				$('#sender-address').val(senderInfoArray[5]);
				$('#sender-tel').val(senderInfoArray[6]);
				$('#sender-fax').val(senderInfoArray[7]);
				$('#sender-url').val(senderInfoArray[8]);
				
				$('#content-main').hide();
				$('#content-input').show();
			}
		}
	}
})();
